<?php
// Файл: modules/admin_users.php

require_once 'scripts/config.php';
require_once 'scripts/admin_functions.php';

// Получение параметров фильтрации и поиска
$search = isset($_GET['search']) ? $_GET['search'] : '';
$filter = isset($_GET['filter']) ? $_GET['filter'] : 'all';

// Получение списка пользователей с учетом фильтрации и поиска
$users = getFilteredUsers($search, $filter);

// Обработка действий (блокировка/разблокировка, верификация)
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $action = $_POST['action'];
    $user_id = $_POST['user_id'];

    switch ($action) {
        case 'block':
            blockUser($user_id);
            break;
        case 'unblock':
            unblockUser($user_id);
            break;
        case 'verify':
            verifyArtist($user_id);
            break;
    }
}
?>

<h2>Управление пользователями</h2>

<!-- Форма поиска и фильтрации -->
<form class="mb-4">
    <div class="row">
        <div class="col-md-6">
            <input type="text" name="search" class="form-control" placeholder="Поиск по имени или email" value="<?php echo htmlspecialchars($search); ?>">
        </div>
        <div class="col-md-4">
            <select name="filter" class="form-control">
                <option value="all" <?php echo $filter == 'all' ? 'selected' : ''; ?>>Все пользователи</option>
                <option value="active" <?php echo $filter == 'active' ? 'selected' : ''; ?>>Активные</option>
                <option value="blocked" <?php echo $filter == 'blocked' ? 'selected' : ''; ?>>Заблокированные</option>
                <option value="verified" <?php echo $filter == 'verified' ? 'selected' : ''; ?>>Верифицированные артисты</option>
            </select>
        </div>
        <div class="col-md-2">
            <button type="submit" class="btn btn-primary w-100">Применить</button>
        </div>
    </div>
</form>

<!-- Таблица пользователей -->
<table class="table table-striped">
    <thead>
        <tr>
            <th>ID</th>
            <th>Имя</th>
            <th>Email</th>
            <th>Статус</th>
            <th>Действия</th>
        </tr>
    </thead>
    <tbody>
        <?php foreach ($users as $user): ?>
            <tr>
                <td><?php echo $user['id']; ?></td>
                <td><?php echo htmlspecialchars($user['name']); ?></td>
                <td><?php echo htmlspecialchars($user['email']); ?></td>
                <td>
                    <?php
                    if ($user['is_blocked']) {
                        echo '<span class="badge bg-danger">Заблокирован</span>';
                    } elseif ($user['is_verified']) {
                        echo '<span class="badge bg-success">Верифицирован</span>';
                    } else {
                        echo '<span class="badge bg-secondary">Обычный</span>';
                    }
                    ?>
                </td>
                <td>
                    <div class="btn-group" role="group">
                        <?php if ($user['is_blocked']): ?>
                            <form method="post">
                                <input type="hidden" name="action" value="unblock">
                                <input type="hidden" name="user_id" value="<?php echo $user['id']; ?>">
                                <button type="submit" class="btn btn-sm btn-warning">Разблокировать</button>
                            </form>
                        <?php else: ?>
                            <form method="post">
                                <input type="hidden" name="action" value="block">
                                <input type="hidden" name="user_id" value="<?php echo $user['id']; ?>">
                                <button type="submit" class="btn btn-sm btn-danger">Заблокировать</button>
                            </form>
                        <?php endif; ?>
                        <?php if (!$user['is_verified']): ?>
                            <form method="post">
                                <input type="hidden" name="action" value="verify">
                                <input type="hidden" name="user_id" value="<?php echo $user['id']; ?>">
                                <button type="submit" class="btn btn-sm btn-success">Верифицировать</button>
                            </form>
                        <?php endif; ?>
                        <button type="button" class="btn btn-sm btn-info" onclick="showUserDetails(<?php echo $user['id']; ?>)">Детали</button>
                    </div>
                </td>
            </tr>
        <?php endforeach; ?>
    </tbody>
</table>

<!-- Модальное окно для отображения деталей пользователя -->
<div class="modal fade" id="userDetailsModal" tabindex="-1" aria-hidden="true">
    <div class="modal-dialog modal-lg">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title">Детали пользователя</h5>
                <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
            </div>
            <div class="modal-body" id="userDetailsContent">
                <!-- Содержимое будет загружено динамически -->
            </div>
        </div>
    </div>
</div>

<script>
function showUserDetails(userId) {
    $.ajax({
        url: 'scripts/admin_actions.php?action=get_user_details',
        type: 'GET',
        data: { user_id: userId },
        success: function(response) {
            $('#userDetailsContent').html(response);
            $('#userDetailsModal').modal('show');
        },
        error: function() {
            alert('Ошибка при загрузке данных пользователя');
        }
    });
}

// Обработка формы редактирования пользователя
$(document).on('submit', '#editUserForm', function(e) {
    e.preventDefault();
    $.ajax({
        url: 'scripts/admin_actions.php?action=update_user',
        type: 'POST',
        data: $(this).serialize(),
        success: function(response) {
            if (response.status === 'success') {
                alert('Данные пользователя обновлены');
                $('#userDetailsModal').modal('hide');
                location.reload(); // Перезагрузка страницы для обновления данных
            } else {
                alert('Ошибка: ' + response.message);
            }
        },
        error: function() {
            alert('Ошибка при обновлении данных пользователя');
        }
    });
});
</script>
