<?php
session_start();
require_once 'config.php';

function registerAdmin($name, $email, $password) {
    global $mysqli;

    // Проверка, существует ли администратор с таким email
    $stmt = $mysqli->prepare("SELECT id FROM admins WHERE email = ?");
    $stmt->bind_param("s", $email);
    $stmt->execute();
    $result = $stmt->get_result();
    if ($result->num_rows > 0) {
        return "Администратор с таким email уже существует";
    }
    $stmt->close();

    // Хеширование пароля
    $hashed_password = password_hash($password, PASSWORD_DEFAULT);

    // Вставка нового администратора в базу данных
    $stmt = $mysqli->prepare("INSERT INTO admins (name, email, password) VALUES (?, ?, ?)");
    $stmt->bind_param("sss", $name, $email, $hashed_password);
    if ($stmt->execute()) {
        $admin_id = $mysqli->insert_id;
        $_SESSION['admin_id'] = $admin_id;
        $_SESSION['admin_name'] = $name;
        return true;
    } else {
        return "Ошибка при регистрации администратора";
    }
}

function loginAdmin($email, $password) {
    global $mysqli;

    // Проверяем, существует ли администратор с таким email
    $stmt = $mysqli->prepare("SELECT id, name, password FROM admins WHERE email = ?");
    $stmt->bind_param("s", $email);
    $stmt->execute();
    $result = $stmt->get_result();

    if ($result->num_rows === 0) {
        return "Администратор с таким email не найден";
    }

    $admin = $result->fetch_assoc();

    // Проверяем пароль
    if (password_verify($password, $admin['password'])) {
        $_SESSION['admin_id'] = $admin['id'];
        $_SESSION['admin_name'] = $admin['name'];
        return true;
    } else {
        return "Неверный пароль";
    }
}

function isAdminLoggedIn() {
    return isset($_SESSION['admin_id']);
}

function logoutAdmin() {
    unset($_SESSION['admin_id']);
    unset($_SESSION['admin_name']);
    session_destroy();
}
