<?php
session_start();
require_once 'config.php';
require_once 'auth.php';

function processUserRequest($action) {
    global $mysqli;

    switch ($action) {
        case 'update_profile':
            if ($_SERVER['REQUEST_METHOD'] === 'POST') {
                $user_id = $_SESSION['user_id'];
                $name = $_POST['name'];
                $phone = $_POST['phone'];

                $stmt = $mysqli->prepare("UPDATE users SET name = ?, phone = ? WHERE id = ?");
                $stmt->bind_param("ssi", $name, $phone, $user_id);

                if ($stmt->execute()) {
                    return json_encode(['status' => 'success', 'message' => 'Профиль успешно обновлен']);
                } else {
                    return json_encode(['status' => 'error', 'message' => 'Ошибка при обновлении профиля']);
                }
            }
            break;

        case 'change_password':
            if ($_SERVER['REQUEST_METHOD'] === 'POST') {
                $user_id = $_SESSION['user_id'];
                $current_password = $_POST['current_password'];
                $new_password = $_POST['new_password'];

                // Проверка текущего пароля
                $stmt = $mysqli->prepare("SELECT password FROM users WHERE id = ?");
                $stmt->bind_param("i", $user_id);
                $stmt->execute();
                $result = $stmt->get_result();
                $user = $result->fetch_assoc();

                if (password_verify($current_password, $user['password'])) {
                    $hashed_password = password_hash($new_password, PASSWORD_DEFAULT);
                    $update_stmt = $mysqli->prepare("UPDATE users SET password = ? WHERE id = ?");
                    $update_stmt->bind_param("si", $hashed_password, $user_id);

                    if ($update_stmt->execute()) {
                        return json_encode(['status' => 'success', 'message' => 'Пароль успешно изменен']);
                    } else {
                        return json_encode(['status' => 'error', 'message' => 'Ошибка при изменении пароля']);
                    }
                } else {
                    return json_encode(['status' => 'error', 'message' => 'Неверный текущий пароль']);
                }
            }
            break;

        default:
            return json_encode(['status' => 'error', 'message' => 'Неизвестное действие']);
    }
}

// Обработка запроса
if (isset($_GET['action'])) {
    echo processUserRequest($_GET['action']);
}
?>
